It has been identified that the Device ID data type declaration in your privacy policy does not match the actual usage of this data, potentially exposing users to privacy risks and violating data protection regulations.